==> haskell-errors-2.2.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: errors
version: 2.2.1
id: errors-2.2.1-1n5FgR4mpQ2Jw0nLNvC0nv
key: errors-2.2.1-1n5FgR4mpQ2Jw0nLNvC0nv
license: BSD3
copyright: 2012, 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".
    .
    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.
category: Control, Error Handling
author: Gabriel Gonzalez
exposed: True
indefinite: False
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR
abi: 2ba397a02c23470552a8fbc98f17499e
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/errors-2.2.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/errors-2.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/errors-2.2.1
hs-libraries: HSerrors-2.2.1-1n5FgR4mpQ2Jw0nLNvC0nv
depends:
    base-4.10.0.0 exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz transformers-0.5.2.0
    transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v
    unexceptionalio-0.3.0-2Qrq3kcp0PEBvJTmGgkrK4
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=98ab8c145be258d01b7a6333e00858ed
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v=be80f3d454efcaa9a115f9c6da29209c
             unexceptionalio-0.3.0-2Qrq3kcp0PEBvJTmGgkrK4=d815f1748c199a35325736906ef04ee1
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=368aa3ad25486678b8f3fef19ec4be32
haddock-interfaces: /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html: /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-errors-2.2.2-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: errors
version: 2.2.2
id: errors-2.2.2-55dL44uoGvGA1pVVvEb4s7
key: errors-2.2.2-55dL44uoGvGA1pVVvEb4s7
license: BSD3
copyright: 2012, 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".
    .
    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.
category: Control, Error Handling
author: Gabriel Gonzalez
exposed: True
indefinite: False
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR
abi: 7918b249754623c66fa404f9b2e49125
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/errors-2.2.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/errors-2.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/errors-2.2.2
hs-libraries: HSerrors-2.2.2-55dL44uoGvGA1pVVvEb4s7
depends:
    base-4.10.0.0 exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz transformers-0.5.2.0
    transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v
    unexceptionalio-0.3.0-2Qrq3kcp0PEBvJTmGgkrK4
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=98ab8c145be258d01b7a6333e00858ed
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v=be80f3d454efcaa9a115f9c6da29209c
             unexceptionalio-0.3.0-2Qrq3kcp0PEBvJTmGgkrK4=d815f1748c199a35325736906ef04ee1
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=368aa3ad25486678b8f3fef19ec4be32
haddock-interfaces: /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html: /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
